==> Vixio%201.1.1.src.zip: Vixio-1.1.1/src/main/java/me/iblitzkriegi/vixio/util/MultiBotGuildCompare.java <==
package me.iblitzkriegi.vixio.util;

import ch.njol.skript.lang.Expression;
import ch.njol.skript.lang.Literal;
import ch.njol.skript.lang.SkriptEvent;
import ch.njol.skript.lang.SkriptParser;
import com.sedmelluq.discord.lavaplayer.player.AudioPlayer;
import me.iblitzkriegi.vixio.effects.EffLogin;
import me.iblitzkriegi.vixio.events.*;
import net.dv8tion.jda.core.entities.User;
import org.bukkit.event.Event;

/**
 * Created by Blitz on 10/30/2016.
 */

public class MultiBotGuildCompare extends SkriptEvent {
    private Expression<String> sBotName;
    @Override
    public boolean init(Literal<?>[] literals, int i, SkriptParser.ParseResult parseResult) {
        sBotName = (Expression<String>) literals[0];
        return true;

    }

    @Override
    public boolean check(Event e) {
        User user = EffLogin.users.get(sBotName.getSingle(e));
        if(e instanceof EvntGuildMessageReceive) {
            User bot = ((EvntGuildMessageReceive) e).getJDA().getSelfUser();
            if (bot.equals(user)) {
                return true;
            }
        }else if(e instanceof EvntPrivateMessageReceive){
            User bot = ((EvntPrivateMessageReceive) e).getJDA().getSelfUser();
            if (bot.equals(user)) {
                return true;
            }
        }else if(e instanceof EvntGuildMemberJoin){
            User bot = ((EvntGuildMemberJoin) e).getEvntJDA().getSelfUser();
            if (bot.equals(user)) {
                return true;
            }
        }else if(e instanceof EvntGuildMemberLeave){
            User bot = ((EvntGuildMemberLeave) e).getEvntJDA().getSelfUser();
            if (bot.equals(user)) {
                return true;
            }
        }else if(e instanceof EvntUserStatusChange){
            User bot = ((EvntUserStatusChange) e).getEvntJDA().getSelfUser();
            if (bot.equals(user)) {
                return true;
            }
        }else if(e instanceof EvntAudioPlayerTrackStart){
            AudioPlayer player = EffLogin.audioPlayers.get(sBotName.getSingle(e));
            if(player.equals(((EvntAudioPlayerTrackStart)e).getPlayer())){
                return true;
            }
        }else if(e instanceof EvntUserJoinVc) {
            User bot = ((EvntUserJoinVc) e).getEvntJDA().getSelfUser();
            if (bot.equals(user)) {
                return true;
            }
        }else if(e instanceof EvntUserLeaveVc) {
            User bot = ((EvntUserLeaveVc) e).getEvntJDA().getSelfUser();
            if (bot.equals(user)) {
                return true;
            }
        }else if(e instanceof EvntTextChannelCreated) {
            User bot = ((EvntTextChannelCreated) e).getEvntJDA().getSelfUser();
            if (bot.equals(user)) {
                return true;
            }
        }else if(e instanceof EvntTextChannelDeleted) {
            User bot = ((EvntTextChannelDeleted) e).getEvntJDA().getSelfUser();
            if (bot.equals(user)) {
                return true;
            }
        }else if(e instanceof EvntUserAvatarUpdate) {
            User bot = ((EvntUserAvatarUpdate) e).getEvntJDA().getSelfUser();
            if (bot.equals(user)) {
                return true;
            }
        }else if(e instanceof EvntGuildBan) {
            User bot = ((EvntGuildBan) e).getEvntJDA().getSelfUser();
            if (bot.equals(user)) {
                return true;
            }
        }
        return false;
    }

    @Override
    public String toString(Event e, boolean b) {
        return getClass().getName();
    }
}

==> Vixio%201.1.3.src.zip: Vixio-1.1.3/src/main/java/me/iblitzkriegi/vixio/util/MultiBotGuildCompare.java <==
package me.iblitzkriegi.vixio.util;

import ch.njol.skript.lang.Expression;
import ch.njol.skript.lang.Literal;
import ch.njol.skript.lang.SkriptEvent;
import ch.njol.skript.lang.SkriptParser;
import com.sedmelluq.discord.lavaplayer.player.AudioPlayer;
import me.iblitzkriegi.vixio.effects.EffLogin;
import me.iblitzkriegi.vixio.events.*;
import net.dv8tion.jda.core.entities.User;
import org.bukkit.event.Event;

/**
 * Created by Blitz on 10/30/2016.
 */

public class MultiBotGuildCompare extends SkriptEvent {
    private Expression<String> sBotName;
    @Override
    public boolean init(Literal<?>[] literals, int i, SkriptParser.ParseResult parseResult) {
        sBotName = (Expression<String>) literals[0];
        return true;

    }

    @Override
    public boolean check(Event e) {
        User user = EffLogin.users.get(sBotName.getSingle(e));
        if(e instanceof EvntGuildMessageReceive) {
            User bot = ((EvntGuildMessageReceive) e).getJDA().getSelfUser();
            if (bot.equals(user)) {
                return true;
            }
        }else if(e instanceof EvntPrivateMessageReceive){
            User bot = ((EvntPrivateMessageReceive) e).getJDA().getSelfUser();
            if (bot.equals(user)) {
                return true;
            }
        }else if(e instanceof EvntGuildMemberJoin){
            User bot = ((EvntGuildMemberJoin) e).getEvntJDA().getSelfUser();
            if (bot.equals(user)) {
                return true;
            }
        }else if(e instanceof EvntGuildMemberLeave){
            User bot = ((EvntGuildMemberLeave) e).getEvntJDA().getSelfUser();
            if (bot.equals(user)) {
                return true;
            }
        }else if(e instanceof EvntUserStatusChange){
            User bot = ((EvntUserStatusChange) e).getEvntJDA().getSelfUser();
            if (bot.equals(user)) {
                return true;
            }
        }else if(e instanceof EvntAudioPlayerTrackStart){
            AudioPlayer player = EffLogin.audioPlayers.get(sBotName.getSingle(e));
            if(player.equals(((EvntAudioPlayerTrackStart)e).getPlayer())){
                return true;
            }
        }else if(e instanceof EvntUserJoinVc) {
            User bot = ((EvntUserJoinVc) e).getEvntJDA().getSelfUser();
            if (bot.equals(user)) {
                return true;
            }
        }else if(e instanceof EvntUserLeaveVc) {
            User bot = ((EvntUserLeaveVc) e).getEvntJDA().getSelfUser();
            if (bot.equals(user)) {
                return true;
            }
        }else if(e instanceof EvntTextChannelCreated) {
            User bot = ((EvntTextChannelCreated) e).getEvntJDA().getSelfUser();
            if (bot.equals(user)) {
                return true;
            }
        }else if(e instanceof EvntTextChannelDeleted) {
            User bot = ((EvntTextChannelDeleted) e).getEvntJDA().getSelfUser();
            if (bot.equals(user)) {
                return true;
            }
        }else if(e instanceof EvntUserAvatarUpdate) {
            User bot = ((EvntUserAvatarUpdate) e).getEvntJDA().getSelfUser();
            if (bot.equals(user)) {
                return true;
            }
        }else if(e instanceof EvntGuildBan) {
            User bot = ((EvntGuildBan) e).getEvntJDA().getSelfUser();
            if (bot.equals(user)) {
                return true;
            }
        }else if(e instanceof EvntGuildMessageBotSend) {
            User bot = ((EvntGuildMessageBotSend) e).getJDA().getSelfUser();
            if (bot.equals(user)) {
                return true;
            }
        }else if(e instanceof EvntUserStartStreaming) {
            User bot = ((EvntUserStartStreaming) e).getEvntJDA().getSelfUser();
            if (bot.equals(user)) {
                return true;
            }
        }else if(e instanceof EvntAudioPlayerTrackEnd) {
            AudioPlayer player = EffLogin.audioPlayers.get(sBotName.getSingle(e));
            if (player.equals(((EvntAudioPlayerTrackEnd) e).getPlayer())) {
                return true;
            }
        }else if(e instanceof EvntMessageAddReaction) {
            User bot = ((EvntMessageAddReaction) e).getEvntJDA().getSelfUser();
            if (bot.equals(user)) {
                return true;
            }
        }
        return false;
    }

    @Override
    public String toString(Event e, boolean b) {
        return getClass().getName();
    }
}
